import { csv } from 'd3';

const datasetURL =
  'https://gist.githubusercontent.com/SirishaManthena/143d8a4e801946f7437aec508d8f5254/raw/c138d08f102c2b8c7d61957ef9dba2d25e37cf42/nutritionalinfo.csv';

// Load the dataset
csv(datasetURL).then((data) => {
  // Filter the dataset to include only the top 10 most popular items
  const popularItems = [
    'Egg McMuffin',
    'Big Mac',
    'Hamburger',
    'Cheeseburger',
    'Double Cheeseburger',
    'McChicken',
    'Chicken McNuggets (10 piece)',
    'Filet-O-Fish',
    'Large French Fries',
    'Hot Fudge Sundae',
  ];

  const topItemsData = data.filter((item) =>
    popularItems.includes(item.Item),
  );

  // Create the scatter plot
  const margin = {
    top: 50,
    right: 20,
    bottom: 80,
    left: 100,
  };
  const width = 800 - margin.left - margin.right;
  const height = 500 - margin.top - margin.bottom;

  const svg = d3
    .select('#scatter-plot')
    .attr('width', width + margin.left + margin.right)
    .attr('height', height + margin.top + margin.bottom)
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left},${margin.top})`,
    );

  // Define scales for x and y axes
  const xScale = d3
    .scaleBand()
    .domain(topItemsData.map((d) => d.Item))
    .range([0, width])
    .padding(0.1);

  const yScale = d3
    .scaleLinear()
    .domain([
      0,
      d3.max(topItemsData, (d) =>
        Math.max(
          +d.Carbohydrates,
          +d.Protein,
          +d['Total Fat'],
        ),
      ),
    ])
    .range([height, 0]);

  // Create x and y axes
  const xAxis = d3.axisBottom(xScale);
  const yAxis = d3.axisLeft(yScale);

  svg
    .append('g')
    .attr('class', 'x axis')
    .attr('transform', `translate(0, ${height})`)
    .call(xAxis)
    .selectAll('text')
    .style('text-anchor', 'middle')
    .attr('dy', '1em')
    .attr('font-size', '12px')
    .attr('transform', 'rotate(-45)')
    .attr('dx', '-.8em');

  svg.append('g').attr('class', 'y axis').call(yAxis);

  // Add x-axis label
  svg
    .append('text')
    .attr('class', 'x label')
    .attr('text-anchor', 'middle')
    .attr('x', width / 2)
    .attr('y', height + margin.top - 0)
    .text('Menu Item');

  // Add y-axis label
  svg
    .append('text')
    .attr('class', 'y label')
    .attr('text-anchor', 'middle')
    .attr('transform', 'rotate(-90)')
    .attr('x', -height / 2)
    .attr('y', -margin.left + 50)
    .text('Nutritional Values');

  // Add title
  svg
    .append('text')
    .attr('class', 'title')
    .attr('text-anchor', 'middle')
    .attr('x', width / 2)
    .attr('y', -margin.top / 2)
    .text("Nutritional Values of Top 10 McDonald's Items");

  // Create symbols for each data point
  const symbols = svg
    .selectAll('.symbol')
    .data(topItemsData)
    .enter()
    .append('g')
    .attr('class', 'symbol')
    .attr(
      'transform',
      (d) =>
        `translate(${xScale(d.Item) + xScale.bandwidth() / 2}, 0)`,
    );

  symbols
    .append('path')
    .attr('class', 'carbs')
    .attr('d', d3.symbol().type(d3.symbolDiamond).size(100))
    .attr(
      'transform',
      (d) => `translate(0,${yScale(+d.Carbohydrates)})`,
    );

  symbols
    .append('path')
    .attr('class', 'protein')
    .attr('d', d3.symbol().type(d3.symbolCross).size(100))
    .attr(
      'transform',
      (d) => `translate(0,${yScale(+d.Protein)})`,
    );

  symbols
    .append('path')
    .attr('class', 'fat')
    .attr('d', d3.symbol().type(d3.symbolCircle).size(100))
    .attr(
      'transform',
      (d) => `translate(0,${yScale(+d['Total Fat'])})`,
    );
});
